@@ -24,11 +24,14 @@ from django.views.decorators.csrf import csrf_exempt
 from django.core.files.storage import DefaultStorage, default_storage, FileSystemStorage
 
 # FILEBROWSER IMPORTS
-from filebrowser.settings import *
+from filebrowser.settings import STRICT_PIL, DIRECTORY, EXTENSIONS, SELECT_FORMATS, ADMIN_VERSIONS, ADMIN_THUMBNAIL, MAX_UPLOAD_SIZE,\
+    NORMALIZE_FILENAME, CONVERT_FILENAME, SEARCH_TRAVERSE, EXCLUDE, VERSIONS, EXTENSION_LIST, DEFAULT_SORTING_BY, DEFAULT_SORTING_ORDER,\
+    LIST_PER_PAGE, OVERWRITE_EXISTING
 from filebrowser.templatetags.fb_tags import query_helper
 from filebrowser.base import FileListing, FileObject
 from filebrowser.decorators import path_exists, file_exists
 from filebrowser.storage import FileSystemStorageMixin, StorageMixin
+from filebrowser.utils import convert_filename
 from filebrowser import signals
 
 # Add some required methods to FileSystemStorage
@@ -282,7 +285,7 @@ class FileBrowserSite(object):
             filter_re.append(re.compile(exp))
         for k, v in VERSIONS.iteritems():
             exp = (r'_%s(%s)$') % (k, '|'.join(EXTENSION_LIST))
-            filter_re.append(re.compile(exp))
+            filter_re.append(re.compile(exp, re.IGNORECASE))
 
         def filter_browse(item):
             "Defining a browse filter"
@@ -540,19 +543,23 @@ class FileBrowserSite(object):
             folder = fb_uploadurl_re.sub('', folder)
 
             path = os.path.join(self.directory, folder)
-            file_name = os.path.join(path, filedata.name)
-            file_already_exists = self.storage.exists(file_name)
+            # we convert the filename before uploading in order
+            # to check for existing files/folders
+            file_name = convert_filename(filedata.name)
+            filedata.name = file_name
+            file_path = os.path.join(path, file_name)
+            file_already_exists = self.storage.exists(file_path)
 
             # Check for name collision with a directory
-            if file_already_exists and self.storage.isdir(file_name):
-                ret_json = {'success': False, 'filename': filedata.name}
+            if file_already_exists and self.storage.isdir(file_path):
+                ret_json = {'success': False, 'filename': file_name}
                 return HttpResponse(json.dumps(ret_json))
 
             signals.filebrowser_pre_upload.send(sender=request, path=folder, file=filedata, site=self)
             uploadedfile = handle_file_upload(path, filedata, site=self)
 
             if file_already_exists and OVERWRITE_EXISTING:
-                old_file = smart_text(file_name)
+                old_file = smart_text(file_path)
                 new_file = smart_text(uploadedfile)
                 self.storage.move(new_file, old_file, allow_overwrite=True)
             else:
@@ -562,7 +569,7 @@ class FileBrowserSite(object):
             signals.filebrowser_post_upload.send(sender=request, path=folder, file=FileObject(smart_text(file_name), site=self), site=self)
 
             # let Ajax Upload know whether we saved it or not
-            ret_json = {'success': True, 'filename': filedata.name}
+            ret_json = {'success': True, 'filename': file_name}
             return HttpResponse(json.dumps(ret_json))
 
 storage = DefaultStorage()
