@@ -14,28 +14,28 @@ register = template.Library()
 def query_string(context, add=None, remove=None):
     """
     Allows the addition and removal of query string parameters.
-    
+
     _response.html is just {{ response }}
-    
+
     Usage:
     http://www.url.com/{% query_string "param_to_add=value, param_to_add=value" "param_to_remove, params_to_remove" %}
     http://www.url.com/{% query_string "" "filter" %}filter={{new_filter}}
     http://www.url.com/{% query_string "sort=value" "sort" %}
     """
-    
+
     # Written as an inclusion tag to simplify getting the context.
     add = string_to_dict(add)
     remove = string_to_list(remove)
     params = context['query'].copy()
     response = get_query_string(params, add, remove)
-    return {'response': response }
+    return {'response': response}
 
 
 def query_helper(query, add=None, remove=None):
     """
     Helper Function for use within views.
     """
-    
+
     add = string_to_dict(add)
     remove = string_to_list(remove)
     params = query.copy()
@@ -46,9 +46,11 @@ def get_query_string(p, new_params=None, remove=None):
     """
     Add and remove query parameters. From `django.contrib.admin`.
     """
-    
-    if new_params is None: new_params = {}
-    if remove is None: remove = []
+
+    if new_params is None:
+        new_params = {}
+    if remove is None:
+        remove = []
     for r in remove:
         for k in p.keys():
             #if k.startswith(r):
@@ -69,7 +71,7 @@ def string_to_dict(string):
         {{ url|thumbnail:"width=10" }}
         {{ url|thumbnail:"height=20" }}
     """
-    
+
     kwargs = {}
     if string:
         string = str(string)
@@ -78,7 +80,8 @@ def string_to_dict(string):
             string += ','
         for arg in string.split(','):
             arg = arg.strip()
-            if arg == '': continue
+            if arg == '':
+                continue
             kw, val = arg.split('=', 1)
             kwargs[kw] = val
     return kwargs
@@ -89,7 +92,7 @@ def string_to_list(string):
     Usage:
         {{ url|thumbnail:"width,height" }}
     """
-    
+
     args = []
     if string:
         string = str(string)
@@ -98,7 +101,8 @@ def string_to_list(string):
             string += ','
         for arg in string.split(','):
             arg = arg.strip()
-            if arg == '': continue
+            if arg == '':
+                continue
             args.append(arg)
     return args
 
@@ -107,7 +111,7 @@ class SelectableNode(template.Node):
     def __init__(self, filetype, format):
         self.filetype = template.Variable(filetype)
         self.format = template.Variable(format)
-    
+
     def render(self, context):
         try:
             filetype = self.filetype.resolve(context)
@@ -128,14 +132,12 @@ class SelectableNode(template.Node):
 
 
 def selectable(parser, token):
-    
+
     try:
         tag, filetype, format = token.split_contents()
     except:
         raise TemplateSyntaxError, "%s tag requires 2 arguments" % token.contents.split()[0]
-        
+
     return SelectableNode(filetype, format)
-    
+
 register.tag(selectable)
-
-
