@@ -1,10 +1,12 @@
 # coding: utf-8
 
 # PYTHON IMPORTS
+import re
 import os
+import unicodedata
 
 # FILEBROWSER IMPORTS
-from filebrowser.settings import STRICT_PIL
+from filebrowser.settings import STRICT_PIL, NORMALIZE_FILENAME, CONVERT_FILENAME
 
 # PIL import
 if STRICT_PIL:
@@ -16,6 +18,30 @@ else:
         import Image
 
 
+def convert_filename(value):
+    """
+    Convert Filename.
+    """
+
+    if NORMALIZE_FILENAME:
+        chunks = value.split(os.extsep)
+        normalized = []
+        for v in chunks:
+            v = unicodedata.normalize('NFKD', unicode(v)).encode('ascii', 'ignore')
+            v = re.sub(r'[^\w\s-]', '', v).strip()
+            normalized.append(v)
+
+        if len(normalized) > 1:
+            value = '.'.join(normalized)
+        else:
+            value = normalized[0]
+
+    if CONVERT_FILENAME:
+        value = value.replace(" ", "_").lower()
+
+    return value
+
+
 def path_strip(path, root):
     if not path or not root:
         return path
